package com.ruoyi.book.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.book.mapper.BookInfoMapper;
import com.ruoyi.book.domain.BookInfo;
import com.ruoyi.book.service.BookInfoService;

/**
 * 书籍信息Service业务层处理
 *
 * @author DongZeLiang
 * @date 2023-10-09
 */
@Service
public class BookInfoServiceImpl implements BookInfoService {
    @Autowired
    private BookInfoMapper bookInfoMapper;

    /**
     * 查询书籍信息
     *
     * @param id 书籍信息主键
     * @return 书籍信息
     */
    @Override
    public BookInfo selectBookInfoById(Long id) {
        return bookInfoMapper.selectBookInfoById(id);
    }

    /**
     * 查询书籍信息列表
     *
     * @param bookInfo 书籍信息
     * @return 书籍信息
     */
    @Override
    public List<BookInfo> selectBookInfoList(BookInfo bookInfo) {
        return bookInfoMapper.selectBookInfoList(bookInfo);
    }

    /**
     * 新增书籍信息
     *
     * @param bookInfo 书籍信息
     * @return 结果
     */
    @Override
    public int insertBookInfo(BookInfo bookInfo) {
        bookInfo.setCreateBy(SecurityUtils.getUserId());
        bookInfo.setCreateTime(DateUtils.getNowDate());
        return bookInfoMapper.insert(bookInfo);
    }

    /**
     * 修改书籍信息
     *
     * @param bookInfo 书籍信息
     * @return 结果
     */
    @Override
    public int updateBookInfo(BookInfo bookInfo) {
        return bookInfoMapper.updateBookInfo(bookInfo);
    }

    /**
     * 批量删除书籍信息
     *
     * @param ids 需要删除的书籍信息主键
     * @return 结果
     */
    @Override
    public int deleteBookInfoByIds(Long[] ids) {
        return bookInfoMapper.deleteBookInfoByIds(ids);
    }

    /**
     * 删除书籍信息信息
     *
     * @param id 书籍信息主键
     * @return 结果
     */
    @Override
    public int deleteBookInfoById(Long id) {
        return bookInfoMapper.deleteBookInfoById(id);
    }
}
